from pydantic import BaseModel, Field


class ContentRating(BaseModel):
    # acb: str = ''
    # agcom: str = ''
    # anatel: str = ''
    # bbfc: str = ''
    # bfvc: str = ''
    # bmukk: str = ''
    # catv: str = ''
    # catvfr: str = ''
    # cbfc: str = ''
    # ccc: str = ''
    # cce: str = ''
    # chfilm: str = ''
    # chvrs: str = ''
    # cicf: str = ''
    # cna: str = ''
    # cnc: str = ''
    # csa: str = ''
    # csc: str = ''
    # czfilm: str = ''
    # djctq: str = ''
    # ecbm: str = ''
    # eefilm: str = ''
    # egfilm: str = ''
    # eirin: str = ''
    # fcbm: str = ''
    # fco: str = ''
    # fmoc: str = ''
    # fpb: str = ''
    # fpbfl: str = ''
    # fsk: str = ''
    # grfilm: str = ''
    # icaa: str = ''
    # ifco: str = ''
    # ilfilm: str = ''
    # incaa: str = ''
    # kfcb: str = ''
    # kijkwijzer: str = ''
    # kmrb: str = ''
    # lsf: str = ''
    # mccaa: str = ''
    # mccyp: str = ''
    # mcst: str = ''
    # mda: str = ''
    # medietilsynet: str = ''
    # meku: str = ''
    # mf: str = ''
    # mibac: str = ''
    # moc: str = ''
    # moctw: str = ''
    # mpaa: str = ''
    # mpaat: str = ''
    # mtrcb: str = ''
    # nbc: str = ''
    # nbcpl: str = ''
    # nfrc: str = ''
    # nfvcb: str = ''
    # nkclv: str = ''
    # oflc: str = ''
    # pefilm: str = ''
    # rcnof: str = ''
    # resorteviolencia: str = ''
    # rtc: str = ''
    # rte: str = ''
    # russia: str = ''
    # skfilm: str = ''
    # smais: str = ''
    # smsa: str = ''
    # tvpg: str = ''
    # yt: str = ''
    pass
